@@ -34,7 +34,7 @@ class Orden(BaseModel):
     op_tc_clave_ord: types.TipoCuentaOrdenPago = None
     op_cuenta_ord: str = None
     op_rfc_curp_ord: str = None
-    op_ins_clave_ord: digits(3, 5) = types.ClaveOrdenanteOrdenPago.AMU.value
+    op_ins_clave_ord: digits(3, 5)
     # destination info
     op_nom_ben: str = None
     op_tc_clave_ben: types.TipoCuentaOrdenPago = None
@@ -111,8 +111,7 @@ class Orden(BaseModel):
         raise ValueError('must be in YYYYMMDD format')
 
     def build_xml(self):  # noqa: WPS231
-        mensaje = etree.Element('mensaje', categoria=self.categoria)
-        ordenpago = etree.SubElement(mensaje, 'ordenpago', Id=str(self.id))
+        ordenpago = etree.Element('ordenpago', Id=str(self.id))
 
         elements = self.dict(
             exclude_none=True,
@@ -133,10 +132,15 @@ class Orden(BaseModel):
                 subelement = etree.SubElement(ordenpago, upper_camel_case_element)
                 subelement.text = str(value)
 
-        return mensaje
+        return ordenpago
 
     @classmethod
-    def parse_xml(cls, orden_element, categoria: types.CategoriaOrdenPago):
+    def parse_xml(
+        cls,
+        orden_element,
+        categoria: types.CategoriaOrdenPago,
+        origin_institution: types.ClaveOrdenanteOrdenPago = None,
+    ):
         orden_data = {
             'id': orden_element.attrib['Id'],
             'categoria': categoria,
@@ -149,6 +153,9 @@ class Orden(BaseModel):
             if tag == 'op_ins_clave':
                 orden_data['op_ins_clave_ben'] = element.text
 
+        if 'op_ins_clave_ord' not in orden_data:
+            orden_data['op_ins_clave_ord'] = origin_institution
+
         return cls(**orden_data)
 
 
